#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: contravariant-extras
version: 0.3.2
id: contravariant-extras-0.3.2-6d5f1a60e6e892934ce378f020a6eca2
key: contr_F6OC9z8eWTp11hijERPSvu
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/contravariant-extras
synopsis: Extras for the "contravariant" package
category: Control
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    Contravariant.Extras Contravariant.Extras.Contrazip
    Contravariant.Extras.Op Contravariant.Extras.Op.Contrazip
hidden-modules: Contravariant.Extras.TH
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/contravariant-extras-0.3.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/contravariant-extras-0.3.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/contravariant-extras-0.3.2
hs-libraries: HScontravariant-extras-0.3.2-F6OC9z8eWTp11hijERPSvu
depends:
    base-prelude-1-f3d581c11ed30ed2219a781ec92d2bd3
    contravariant-1.4-1b3716257293d15c38698a7852cba3ac
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    tuple-th-0.2.5-ea7f98b57800e457206c4356ae606852
haddock-interfaces: /usr/share/doc/haskell-contravariant-extras/html/contravariant-extras.haddock
haddock-html: /usr/share/doc/haskell-contravariant-extras/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
